@@ -77,9 +77,9 @@ from_numpy = ('ComplexWarning', 'Inf', 'NAN', 'abs', 'absolute', 'add',
               'asanyarray', 'asarray', 'asscalar', 'atleast_1d',
               'atleast_2d', 'atleast_3d', 'average', 'bartlett',
               'bincount', 'bitwise_and', 'bitwise_not', 'bitwise_or',
-              'bitwise_xor', 'blackman', 'bmat', 'bool', 'broadcast',
+              'bitwise_xor', 'blackman', 'bmat', 'broadcast',
               'ceil', 'chararray', 'choose', 'clip', 'column_stack',
-              'common_type', 'complex', 'complex128', 'compress',
+              'common_type', 'complex128', 'compress',
               'concatenate', 'conj', 'conjugate', 'convolve', 'copysign',
               'corrcoef', 'correlate', 'cos', 'cosh', 'cov', 'cross',
               'cumprod', 'cumproduct', 'cumsum', 'datetime_data',
@@ -91,10 +91,10 @@ from_numpy = ('ComplexWarning', 'Inf', 'NAN', 'abs', 'absolute', 'add',
               'eye', 'fabs', 'fastCopyAndTranspose', 'fft',
               'fill_diagonal', 'find_common_type', 'finfo', 'fix',
               'flatiter', 'flatnonzero', 'flexible', 'fliplr', 'flipud',
-              'float', 'float64', 'floor', 'floor_divide', 'fmax', 'fmin',
+              'float64', 'floor', 'floor_divide', 'fmax', 'fmin',
               'fmod', 'format_parser', 'frexp', 'frombuffer', 'fromfile',
               'fromfunction', 'fromiter', 'frompyfunc', 'fromregex',
-              'fromstring', 'fv', 'genfromtxt', 'get_array_wrap',
+              'fromstring', 'genfromtxt', 'get_array_wrap',
               'get_include', 'get_numarray_include', 'get_numpy_include',
               'get_printoptions', 'getbuffer', 'getbufsize', 'geterr',
               'geterrcall', 'geterrobj', 'gradient', 'greater',
@@ -102,9 +102,9 @@ from_numpy = ('ComplexWarning', 'Inf', 'NAN', 'abs', 'absolute', 'add',
               'histogram2d', 'histogramdd', 'hsplit', 'hstack', 'hypot',
               'i0', 'identity', 'iinfo', 'imag', 'in1d', 'index_exp',
               'indices', 'inexact', 'inf', 'info', 'infty', 'inner',
-              'insert', 'int', 'int32', 'int_asbuffer',
+              'insert', 'int32', 'int_asbuffer',
               'integer', 'interp', 'intersect1d', 'intersect1d_nu',
-              'invert', 'ipmt', 'irr', 'iscomplex', 'iscomplexobj',
+              'invert', 'iscomplex', 'iscomplexobj',
               'isfinite', 'isinf', 'isnan', 'isneginf', 'isposinf',
               'isreal', 'isrealobj', 'isscalar', 'issctype', 'issubclass_',
               'issubdtype', 'issubsctype', 'iterable', 'kaiser', 'kron',
@@ -112,23 +112,23 @@ from_numpy = ('ComplexWarning', 'Inf', 'NAN', 'abs', 'absolute', 'add',
               'lib', 'linalg', 'linspace', 'little_endian', 'loadtxt',
               'log', 'log10', 'log1p', 'log2', 'logaddexp', 'logaddexp2',
               'logical_and', 'logical_not', 'logical_or', 'logical_xor',
-              'logspace', 'long', 'longcomplex', 'longdouble', 'longfloat',
+              'logspace', 'longcomplex', 'longdouble', 'longfloat',
               'longlong', 'lookfor', 'ma', 'mafromtxt', 'mask_indices',
               'mat', 'math', 'matrix', 'matrixlib', 'max', 'maximum',
               'maximum_sctype', 'may_share_memory', 'mean', 'median',
               'memmap', 'meshgrid', 'mgrid', 'min', 'minimum',
-              'mintypecode', 'mirr', 'mod', 'modf', 'msort', 'multiply',
+              'mintypecode', 'mod', 'modf', 'msort', 'multiply',
               'nan', 'nan_to_num', 'nanargmax', 'nanargmin', 'nanmax',
               'nanmin', 'nansum', 'nbytes', 'ndarray', 'ndenumerate',
               'ndfromtxt', 'ndim', 'ndindex', 'negative', 'newaxis',
-              'newbuffer', 'nextafter', 'nonzero', 'not_equal', 'nper',
-              'npv', 'number', 'obj2sctype', 'object', 'object0',
+              'newbuffer', 'nextafter', 'nonzero', 'not_equal', 
+               'number', 'obj2sctype', 'object0',
               'object_', 'ogrid', 'ones', 'ones_like', 'outer', 'packbits',
-              'percentile', 'pi', 'piecewise', 'pkgload', 'place', 'pmt',
+              'percentile', 'pi', 'piecewise', 'pkgload', 'place', 
               'poly', 'poly1d', 'polyadd', 'polyder', 'polydiv', 'polyfit',
               'polyint', 'polymul', 'polynomial', 'polysub', 'polyval',
-              'power', 'ppmt', 'prod', 'product', 'ptp', 'put', 'putmask',
-              'pv', 'rad2deg', 'radians', 'random', 'rank', 'rate',
+              'power', 'prod', 'product', 'ptp', 'put', 'putmask',
+              'rad2deg', 'radians', 'random', 'rank', 
               'ravel', 'real', 'real_if_close', 'rec', 'recarray',
               'recfromcsv', 'recfromtxt', 'reciprocal', 'record',
               'remainder', 'repeat', 'require', 'reshape', 'resize',
