@@ -545,16 +545,29 @@ class ColumnDataFileFrame(wx.Frame) :
             reader = 'read_gsescan'
         if 'epics stepscan file' in line1:
             reader = 'read_gsexdi'
-        elif 'xdi' in line1:
+        if 'xdi' in line1:
             reader = 'read_xdi'
+        if ("#s" in line1) or ("#f" in line1):
+            reader = 'read_specfile'
 
         if reader in ('read_xdi', 'read_gsexdi'):
             # first check for Nans and Infs
             nan_result = look_for_nans(path)
+            if 'read error' in nan_result.message:
+                title = "Cannot read %s" % path
+                message = "Error reading %s\n%s" %(path, nan_result.message)
+                r = Popup(self.parent, message, title)
+                return None
+            if 'no data' in nan_result.message:
+                title = "No data in %s" % path
+                message = "No data found in file %s" % path
+                r = Popup(self.parent, message, title)
+                return None
+
             if ('has nans' in nan_result.message or
                 'has infs' in nan_result.message):
                 reader = 'read_ascii'
-        
+
         tmpname = '_tmp_file_'
         read_cmd = "%s = %s('%s')" % (tmpname, reader, path)
         self.reader = reader
@@ -575,9 +588,8 @@ class ColumnDataFileFrame(wx.Frame) :
             title = "Cannot read %s" % path
             r = Popup(self.parent, "\n".join(msg), title)
             return None
-
         group = _larch.symtable.get_symbol(tmpname)
-        _larch.symtable.del_symbol(tmpname)
+        # _larch.symtable.del_symbol(tmpname)
 
         group.text = text
         group.path = path
