@@ -70,6 +70,7 @@ class EXAFSPanel(TaskPanel):
     def __init__(self, parent, controller, **kws):
         TaskPanel.__init__(self, parent, controller,
                            configname='exafs_config',
+                           title='EXAFS Background Subtraction and Fourier Transforms',
                            config=defaults, **kws)
         self.skip_process = False
         self.last_plot = 'one'
@@ -156,7 +157,8 @@ class EXAFSPanel(TaskPanel):
                           action=partial(self.onCopyParam, name))
 
 
-        panel.Add(SimpleText(panel, ' EXAFS Processing', **self.titleopts), dcol=5)
+        panel.Add(SimpleText(panel, 'EXAFS Data Reduction and Fourier Transforms',
+                             size=(350, -1),  **self.titleopts), style=LEFT, dcol=6)
 
         panel.Add(plot_sel, newrow=True)
         panel.Add(self.wids['plotsel_op'], dcol=2)
@@ -178,7 +180,7 @@ class EXAFSPanel(TaskPanel):
 
         panel.Add(HLine(panel, size=(500, 3)), dcol=6, newrow=True)
 
-        panel.Add(SimpleText(panel, ' Background subtraction', size=(180, -1),
+        panel.Add(SimpleText(panel, ' Background subtraction', size=(200, -1),
                              **self.titleopts), dcol=2, style=LEFT, newrow=True)
         panel.Add(SimpleText(panel, 'Copy To Selected Groups:'),
                   style=RIGHT, dcol=3)
@@ -215,7 +217,7 @@ class EXAFSPanel(TaskPanel):
 
         panel.Add(HLine(panel, size=(500, 3)), dcol=6, newrow=True)
 
-        panel.Add(SimpleText(panel, ' Fourier transform    ', size=(180, -1),
+        panel.Add(SimpleText(panel, ' Fourier transform    ', size=(200, -1),
                              **self.titleopts), dcol=2, style=LEFT, newrow=True)
         panel.Add(SimpleText(panel, 'Copy To Selected Groups:'),
                   style=RIGHT, dcol=3)
@@ -258,13 +260,11 @@ class EXAFSPanel(TaskPanel):
         """get and set processing configuration for a group"""
         if dgroup is None:
             dgroup = self.controller.get_group()
-        # print("EXAFS panel get_config ", dgroup)
+
         conf = getattr(dgroup, self.configname, self.get_defaultconfig())
-        # print("EXAFS panel get_config ", conf.get('e0', -123.))
 
         bkg_kmax = conf.get('bkg_kmax', None)
         fft_kmax = conf.get('fft_kmax', None)
-
         if None in (bkg_kmax, fft_kmax):
             e0 = conf.get('e0', -1)
             emin = min(dgroup.energy)
@@ -277,6 +277,22 @@ class EXAFSPanel(TaskPanel):
             if fft_kmax is None or fft_kmax < 0:
                 conf['fft_kmax'] = kmax - 1
 
+        if hasattr(dgroup, 'bkg_params'): # from Athena
+            conf['e0'] =  dgroup.bkg_params.e0
+            conf['rbkg'] =  dgroup.bkg_params.rbkg
+            conf['bkg_kmin'] =  dgroup.bkg_params.spl1
+            conf['bkg_kmax'] =  dgroup.bkg_params.spl2
+            conf['bkg_kweight'] =  dgroup.bkg_params.kw
+            conf['bkg_clamplo'] =  dgroup.bkg_params.clamp1
+            conf['bkg_clamphi'] =  dgroup.bkg_params.clamp2
+
+        if hasattr(dgroup, 'fft_params'): # from Athena
+            conf['fft_kmin'] =  dgroup.fft_params.kmin
+            conf['fft_kmax'] =  dgroup.fft_params.kmax
+            conf['fft_dk'] =  dgroup.fft_params.dk
+            conf['fft_kweight'] =  dgroup.fft_params.kw
+            conf['fft_kwindow'] =  dgroup.fft_params.kwindow
+
         if dgroup is not None:
             setattr(dgroup, self.configname, conf)
         return conf
