@@ -32,10 +32,11 @@ from larch.utils.strutils import (file2groupname, unique_name,
 from larch.larchlib import read_workdir, save_workdir, read_config, save_config
 
 from larch.wxlib import (LarchFrame, ColumnDataFileFrame, AthenaImporter,
-                         FileCheckList, FloatCtrl, SetTip, get_icon,
-                         SimpleText, pack, Button, Popup, HLine, FileSave,
-                         Choice, Check, MenuItem, GUIColors, CEN,
-                         LEFT, FRAMESTYLE, Font, FONTSIZE, flatnotebook)
+                         SpecfileImporter, FileCheckList, FloatCtrl,
+                         SetTip, get_icon, SimpleText, pack, Button, Popup,
+                         HLine, FileSave, Choice, Check, MenuItem,
+                         GUIColors, CEN, LEFT, FRAMESTYLE, Font, FONTSIZE,
+                         flatnotebook)
 
 from larch.wxlib.plotter import _newplot, _plot, last_cursor_pos
 
@@ -56,15 +57,15 @@ from .xas_dialogs import (MergeDialog, RenameDialog, RemoveDialog,
                           OverAbsorptionDialog, DeconvolutionDialog,
                           SpectraCalcDialog,  QuitDialog)
 
-from larch.io import (read_ascii, read_xdi, read_gsexdi,
-                      gsescan_group, fix_varname, groups2csv,
-                      is_athena_project, AthenaProject, make_hashkey)
+from larch.io import (read_ascii, read_xdi, read_gsexdi, gsescan_group,
+                      fix_varname, groups2csv, is_athena_project,
+                      AthenaProject, make_hashkey, is_specfile, open_specfile)
 
 from larch.xafs import pre_edge, pre_edge_baseline
 
 LEFT = wx.ALIGN_LEFT
 CEN |=  wx.ALL
-FILE_WILDCARDS = "Data Files(*.0*,*.dat,*.xdi,*.prj)|*.0*;*.dat;*.xdi;*.prj|All files (*.*)|*.*"
+FILE_WILDCARDS = "Data Files(*.0*,*.dat,*.xdi,*.prj,*.spc)|*.0*;*.dat;*.DAT;*.xdi;*.prj;*.spc|All files (*.*)|*.*"
 
 ICON_FILE = 'onecone.ico'
 XASVIEW_SIZE = (950, 750)
@@ -103,8 +104,7 @@ def assign_gsescan_groups(group):
 
 class XASController():
     """
-    class hollding the Larch session and doing the
-    processing work for Larch XAS GUI
+    class holding the Larch session and doing the processing work for XAS GUI
     """
     config_file = 'xas_viewer.conf'
     def __init__(self, wxparent=None, _larch=None):
@@ -452,7 +452,8 @@ class XASFrame(wx.Frame):
         ir = 0
         sizer.Add(self.title, 0, LEFT|wx.GROW|wx.ALL, 1)
         self.nb = flatnotebook(panel, NB_PANELS,
-                               panelkws=dict(controller=self.controller),
+                               panelkws=dict(xasmain=self,
+                                             controller=self.controller),
                                on_change=self.onNBChanged)
         sizer.Add(self.nb, 1, LEFT|wx.EXPAND, 2)
         pack(panel, sizer)
@@ -460,7 +461,19 @@ class XASFrame(wx.Frame):
         splitter.SplitVertically(leftpanel, panel, 1)
         wx.CallAfter(self.init_larch)
 
+    def get_nbpage(self, name):
+        "get nb page by name"
+        name = name.lower()
+        for page in self.nb.pagelist:
+            if name in page.__class__.__name__.lower():
+                return page
+
     def onNBChanged(self, event=None):
+        is_prepeak = self.nb.GetCurrentPage() is self.get_nbpage('prepeak')
+        for imenu, menudat in enumerate(self.menubar.GetMenus()):
+            if 'pre-edge' in menudat[1].lower():
+                self.menubar.EnableTop(imenu, is_prepeak)
+
         callback = getattr(self.nb.GetCurrentPage(), 'onPanelExposed', None)
         if callable(callback):
             callback()
@@ -535,7 +548,7 @@ class XASFrame(wx.Frame):
         fmenu = wx.Menu()
         group_menu = wx.Menu()
         data_menu = wx.Menu()
-        # ppeak_menu = wx.Menu()
+        ppeak_menu = wx.Menu()
         m = {}
 
         MenuItem(self, fmenu, "&Open Data File\tCtrl+O",
@@ -614,9 +627,14 @@ class XASFrame(wx.Frame):
         MenuItem(self, data_menu, "Add and Subtract Sepctra",
                  "Calculations of Spectra",  self.onSpectraCalc)
 
+        MenuItem(self, ppeak_menu, "Load Pre-edge Peak Model",
+                 "Load saved model for Pre-edge Peak Fitting",
+                 self.onPrePeakLoad)
+
         self.menubar.Append(fmenu, "&File")
         self.menubar.Append(group_menu, "Groups")
         self.menubar.Append(data_menu, "Data")
+        self.menubar.Append(ppeak_menu, "Pre-edge Peaks")
 
         # self.menubar.Append(ppeak_menu, "PreEdgePeaks")
         self.SetMenuBar(self.menubar)
@@ -689,6 +707,12 @@ class XASFrame(wx.Frame):
 
         if outfile is None:
             return
+        if os.path.exists(outfile):
+            if wx.ID_YES != Popup(self,
+                                  "Overwrite existing Project File?",
+                                  "Overwrite existing file?", style=wx.YES_NO):
+                return
+
         aprj = AthenaProject(filename=outfile, _larch=self.larch)
         for label, grp in zip(grouplist, savegroups):
             aprj.add_group(grp)
@@ -828,6 +852,11 @@ class XASFrame(wx.Frame):
     def onDeconvolveData(self, event=None):
         DeconvolutionDialog(self, self.controller).Show()
 
+    def onPrePeakLoad(self, event=None):
+        thispage = self.nb.GetCurrentPage()
+        if 'prepeak' in thispage.__class__.__name__.lower():
+            thispage.onLoadFitResult()
+
     def onConfigDataFitting(self, event=None):
         pass
 
@@ -925,17 +954,54 @@ class XASFrame(wx.Frame):
 
         # check for athena projects
         if is_athena_project(path):
-            kwargs = dict(filename=path,
-                          _larch=self.controller.larch,
-                          read_ok_cb=self.onReadAthenaProject_OK)
-            self.show_subframe('athena_import', AthenaImporter, **kwargs)
+            self.show_subframe('athena_import', AthenaImporter,
+                               filename=path,
+                               _larch=self.controller.larch,
+                               read_ok_cb=self.onReadAthenaProject_OK)
+        # check for Spec File
+        elif is_specfile(path):
+            self.show_subframe('spec_import', SpecfileImporter,
+                               filename=path,
+                               read_ok_cb=self.onReadSpecfile_OK)
+        # default to Column File
         else:
-            kwargs = dict(filename=path,
-                          _larch=self.larch_buffer.larchshell,
-                          last_array_sel = self.last_array_sel,
-                          read_ok_cb=self.onRead_OK)
+            self.show_subframe('readfile', ColumnDataFileFrame,
+                               filename=path,
+                               _larch=self.larch_buffer.larchshell,
+                               last_array_sel = self.last_array_sel,
+                               read_ok_cb=self.onRead_OK)
+
+    def onReadSpecfile_OK(self, script, path, scanlist):
+        """read groups from a list of scans from a specfile"""
+        self.larch.eval("_specfile = specfile('{path:s}')".format(path=path))
+        dgroup = None
+        _path, fname = os.path.split(path)
+        first_group = None
+        cur_panel = self.nb.GetCurrentPage()
+        cur_panel.skip_plotting = True
+        symtable = self.larch.symtable
+        for scan in scanlist:
+            gname = fix_varname("{:s}{:s}".format(fname[:6], scan))
+            if hasattr(symtable, gname):
+                n = 0
+                while n < 99000:
+                    n += 1
+                    gname = fix_varname("{:s}_{%d}".format(gname, n))
+            
+            cur_panel.skip_plotting = (scan == scanlist[-1])
+            displayname = "%s_scan%s" % (fname, scan)
+            if first_group is None:
+                first_group = gname
+            self.larch.eval(script.format(group=gname, path=path,
+                                          scan=scan))
+            dgroup = self.install_group(gname, displayname,
+                                        process=True, plot=False)
+        cur_panel.skip_plotting = False
+
+        if first_group is not None:
+            self.ShowFile(groupname=first_group, process=True, plot=True)
+        self.write_message("read %d datasets from %s" % (len(scanlist), path))
 
-            self.show_subframe('readfile', ColumnDataFileFrame, **kwargs)
 
     def onReadAthenaProject_OK(self, path, namelist):
         """read groups from a list of groups from an athena project file"""
@@ -965,6 +1031,7 @@ class XASFrame(wx.Frame):
             self.ShowFile(groupname=gname, process=True, plot=True)
         self.write_message("read %d datasets from %s" % (len(namelist), path))
 
+
     def onRead_OK(self, script, path, groupname=None, filename=None,
                   array_sel=None, overwrite=False):
         """ called when column data has been selected and is ready to be used
@@ -1029,7 +1096,10 @@ class XASFrame(wx.Frame):
                       process=True, rebin=False, plot=True):
         """add groupname / filename to list of available data groups"""
 
-        thisgroup = getattr(self.larch.symtable, groupname)
+        try:
+            thisgroup = getattr(self.larch.symtable, groupname)
+        except AttributeError:
+            thisgroup = self.larch.symtable.new_group(groupname)
 
         datatype = getattr(thisgroup, 'datatype', 'raw')
         # file /group may already exist in list
